Lessons
=======

Here listed are the various SPICE lessons provided by the NAIF translated to
use python code examples. Please refer to the NAIF lesson files for the kernel
files needed to complete the exercises and to obtain the full content naiflessons_.

.. _naiflessons: https://naif.jpl.nasa.gov/pub/naif/toolkit_docs/Lessons/

Contents:

.. toctree::
   :maxdepth: 0

   basics
   remote_sensing
   event_finding
   insitu_sensing
   binary_pck
   other_stuff


